Enum wasmtime_jit::SetupError [−][src]
pub enum SetupError {
Validate(String),
Compile(CompileError),
Instantiate(InstantiationError),
DebugInfo(Error),
}Expand description
An error condition while setting up a wasm instance, be it validation, compilation, or instantiation.
Variants
Validate(String)The module did not pass validation.
Tuple Fields of Validate
0: StringCompile(CompileError)A wasm translation error occurred.
Tuple Fields of Compile
0: CompileErrorInstantiate(InstantiationError)Some runtime resource was unavailable or insufficient, or the start function trapped.
Tuple Fields of Instantiate
DebugInfo(Error)Debug information generation error occurred.
Tuple Fields of DebugInfo
0: ErrorTrait Implementations
Performs the conversion.
Performs the conversion.