Struct wasmtime_jit::CodeMemory [−][src]
pub struct CodeMemory { /* fields omitted */ }Expand description
Memory manager for executable code.
Implementations
pub fn allocate_for_function<'a>(
&mut self,
func: &'a CompiledFunction
) -> Result<&mut [VMFunctionBody], String>
pub fn allocate_for_function<'a>(
&mut self,
func: &'a CompiledFunction
) -> Result<&mut [VMFunctionBody], String>
Allocate a continuous memory block for a single compiled function. TODO: Reorganize the code that calls this to emit code directly into the mmap region rather than into a Vec that we need to copy in.