Struct wasmtime_jit::CompilationArtifacts [−][src]
pub struct CompilationArtifacts { /* fields omitted */ }Expand description
Contains all compilation artifacts.
Implementations
pub fn build(
compiler: &Compiler,
data: &[u8],
use_paged_mem_init: bool
) -> Result<(usize, Vec<CompilationArtifacts>, TypeTables), SetupError>
pub fn build(
compiler: &Compiler,
data: &[u8],
use_paged_mem_init: bool
) -> Result<(usize, Vec<CompilationArtifacts>, TypeTables), SetupError>
Creates a CompilationArtifacts for a singular translated wasm module.
The use_paged_init argument controls whether or not an attempt is made to
organize linear memory initialization data as entire pages or to leave
the memory initialization data as individual segments.