Struct wasmtime_jit::SymbolizeContext [−][src]
pub struct SymbolizeContext { /* fields omitted */ }Expand description
A context which contains dwarf debug information to translate program counters back to filenames and line numbers.
Implementations
Returns access to the addr2line::Context which can be used to query
frame information with.
Returns the offset of the code section in the original wasm file, used to calculate lookup values into the DWARF.