[−][src]Crate wasmtime_jit
JIT-style runtime for WebAssembly using Cranelift.
Structs
| CompiledModule | A compiled wasm module, ready to be instantiated. |
| Compiler | A WebAssembly code JIT compiler. |
| Context | A convenient context for compiling and executing WebAssembly instances. |
| Features | The collection of features configurable during compilation |
| InstanceHandle | A handle holding an |
| Namespace | A namespace containing instances keyed by name. |
| NullResolver |
|
| UnknownInstance | Indicates an unknown instance was specified. |
Enums
| ActionError | An error detected while invoking a wasm function or reading a wasm global.
Note that at this level, traps are not reported errors, but are rather
returned through |
| ActionOutcome | The result of invoking a wasm function or reading a wasm global. |
| ContextError | Error message used by |
| InstantiationError | An error while instantiating a module. |
| RuntimeValue | A runtime value. |
| SetupError | An error condition while setting up a wasm instance, be it validation, compilation, or instantiation. |
Constants
| VERSION | Version number of this crate. |
Traits
| Resolver | Import resolver connects imports with available exported values. |
Functions
| instantiate | Create a new wasm instance by compiling the wasm module in |
| link_module | Links a module that has been compiled with |
| target_tunables | Return a |