[−][src]Enum wasmtime_jit::ActionError
An error detected while invoking a wasm function or reading a wasm global.
Note that at this level, traps are not reported errors, but are rather
returned through ActionOutcome.
Variants
Setup(SetupError)An internal implementation error occurred.
Field(String)No field with the specified name was present.
Kind(String)The field was present but was the wrong kind (eg. function, table, global, or memory).
Type(String)The field was present but was the wrong type (eg. i32, i64, f32, or f64).