[−][src]Enum wasmtime_jit::RuntimeValue
A runtime value.
Variants
I32(i32)A runtime value with type i32.
I64(i64)A runtime value with type i64.
F32(u32)A runtime value with type f32.
F64(u64)A runtime value with type f64.
Methods
impl RuntimeValue[src]
pub fn value_type(self) -> Type[src]
Return the type of this RuntimeValue.
pub fn unwrap_i32(self) -> i32[src]
Assuming this RuntimeValue holds an i32, return that value.
pub fn unwrap_i64(self) -> i64[src]
Assuming this RuntimeValue holds an i64, return that value.
pub fn unwrap_f32(self) -> f32[src]
Assuming this RuntimeValue holds an f32, return that value.
pub fn unwrap_f32_bits(self) -> u32[src]
Assuming this RuntimeValue holds an f32, return the bits of that value as a u32.
pub fn unwrap_f64(self) -> f64[src]
Assuming this RuntimeValue holds an f64, return that value.
pub fn unwrap_f64_bits(self) -> u64[src]
Assuming this RuntimeValue holds an f64, return the bits of that value as a u64.