Enum wasmtime_jit::SetupError [−][src]
pub enum SetupError {
Validate(String),
Compile(CompileError),
Instantiate(InstantiationError),
DebugInfo(Error),
}Expand description
An error condition while setting up a wasm instance, be it validation, compilation, or instantiation.
Variants
The module did not pass validation.
Tuple Fields of Validate
0: StringA wasm translation error occurred.
Tuple Fields of Compile
0: CompileErrorSome runtime resource was unavailable or insufficient, or the start function trapped.
Tuple Fields of Instantiate
Debug information generation error occurred.
Tuple Fields of DebugInfo
0: ErrorTrait Implementations
Performs the conversion.
Performs the conversion.