Enum wasmtime_jit::SetupError [−][src]
pub enum SetupError {
Validate(String),
Compile(CompileError),
Instantiate(InstantiationError),
DebugInfo(Error),
}Expand description
An error condition while setting up a wasm instance, be it validation, compilation, or instantiation.
Variants
Validate(String)The module did not pass validation.
Compile(CompileError)A wasm translation error occurred.
Instantiate(InstantiationError)Some runtime resource was unavailable or insufficient, or the start function trapped.
DebugInfo(Error)Debug information generation error occurred.