[−][src]Enum wasmtime_jit::SetupError
An error condition while setting up a wasm instance, be it validation, compilation, or instantiation.
Variants
Validate(String)The module did not pass validation.
Compile(CompileError)A wasm translation error occured.
Instantiate(InstantiationError)Some runtime resource was unavailable or insufficient, or the start function trapped.
DebugInfo(Error)Debug information generation error occured.