pub struct CodeMemory { /* private fields */ }
Memory manager for executable code.

Implementations

Create a new CodeMemory instance.

Allocate a continuous memory block for a single compiled function. TODO: Reorganize the code that calls this to emit code directly into the mmap region rather than into a Vec that we need to copy in.

Make all allocated memory executable.

Returns all published segment ranges.