[−][src]Struct wasmtime_jit::CodeMemory
Memory manager for executable code.
Implementations
impl CodeMemory[src]
pub fn new() -> Self[src]
Create a new CodeMemory instance.
pub fn allocate_for_function<'a>(
&mut self,
func: &'a CompiledFunction
) -> Result<&mut [VMFunctionBody], String>[src]
&mut self,
func: &'a CompiledFunction
) -> Result<&mut [VMFunctionBody], String>
Allocate a continuous memory block for a single compiled function. TODO: Reorganize the code that calls this to emit code directly into the mmap region rather than into a Vec that we need to copy in.
pub fn allocate_for_compilation(
&mut self,
compilation: &Compilation
) -> Result<Box<[&mut [VMFunctionBody]]>, String>[src]
&mut self,
compilation: &Compilation
) -> Result<Box<[&mut [VMFunctionBody]]>, String>
Allocate a continuous memory block for a compilation.
pub fn publish(&mut self, isa: &dyn TargetIsa)[src]
Make all allocated memory executable.
pub fn published_ranges<'a>(
&'a self
) -> impl Iterator<Item = (usize, usize)> + 'a[src]
&'a self
) -> impl Iterator<Item = (usize, usize)> + 'a
Returns all published segment ranges.