Struct wasmtime_jit::CompiledModule[][src]

pub struct CompiledModule { /* fields omitted */ }
A compiled wasm module, ready to be instantiated.

Implementations

Creates a list of compiled modules from the given list of compilation artifacts.

Creates CompiledModule directly from CompilationArtifacts.

Extracts CompilationArtifacts from the compiled module.

Return a reference-counting pointer to a module.

Return a reference to a mutable module (if possible).

Returns the map of all finished JIT functions compiled for this module

Returns the per-signature trampolines for this module.

Returns the stack map information for all functions defined in this module.

The iterator returned iterates over the span of the compiled function in memory with the stack maps associated with those bytes.

Lookups a defined function by a program counter value.

Returns the defined function index, the start address, and the end address (exclusive).

Gets the function information for a given function index.

Returns all ranges covered by JIT code.

Returns module’s JIT code.

Creates a new symbolication context which can be used to further symbolicate stack traces.

Basically this makes a thing which parses debuginfo and can tell you what filename and line number a wasm pc comes from.

Returns whether the original wasm module had unparsed debug information based on the tunables configuration.