Struct wasmtime_jit::CompiledModule [−][src]
pub struct CompiledModule { /* fields omitted */ }Expand description
A compiled wasm module, ready to be instantiated.
Implementations
pub fn from_artifacts_list(
artifacts: Vec<CompilationArtifacts>,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Vec<Arc<Self>>, SetupError>
pub fn from_artifacts_list(
artifacts: Vec<CompilationArtifacts>,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Vec<Arc<Self>>, SetupError>
Creates a list of compiled modules from the given list of compilation artifacts.
pub fn from_artifacts(
artifacts: CompilationArtifacts,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Arc<Self>, SetupError>
pub fn from_artifacts(
artifacts: CompilationArtifacts,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Arc<Self>, SetupError>
Creates CompiledModule directly from CompilationArtifacts.
Extracts CompilationArtifacts from the compiled module.
Return a reference to a mutable module (if possible).
Returns the map of all finished JIT functions compiled for this module
Returns the per-signature trampolines for this module.
pub fn stack_maps(
&self
) -> impl Iterator<Item = (*mut [VMFunctionBody], &[StackMapInformation])>
pub fn stack_maps(
&self
) -> impl Iterator<Item = (*mut [VMFunctionBody], &[StackMapInformation])>
Returns the stack map information for all functions defined in this module.
The iterator returned iterates over the span of the compiled function in memory with the stack maps associated with those bytes.
Lookups a defined function by a program counter value.
Returns the defined function index, the start address, and the end address (exclusive).
Gets the function information for a given function index.
Returns all ranges covered by JIT code.
Returns module’s JIT code.
Creates a new symbolication context which can be used to further symbolicate stack traces.
Basically this makes a thing which parses debuginfo and can tell you what filename and line number a wasm pc comes from.
Returns whether the original wasm module had unparsed debug information based on the tunables configuration.