Struct wasmtime_jit::CompiledModule [−][src]
pub struct CompiledModule { /* fields omitted */ }Expand description
A compiled wasm module, ready to be instantiated.
Implementations
impl CompiledModule[src]
impl CompiledModule[src]pub fn from_artifacts_list(
artifacts: Vec<CompilationArtifacts>,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Vec<Arc<Self>>, SetupError>[src]
pub fn from_artifacts_list(
artifacts: Vec<CompilationArtifacts>,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Vec<Arc<Self>>, SetupError>[src]Creates a list of compiled modules from the given list of compilation artifacts.
pub fn from_artifacts(
artifacts: CompilationArtifacts,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Arc<Self>, SetupError>[src]
pub fn from_artifacts(
artifacts: CompilationArtifacts,
isa: &dyn TargetIsa,
profiler: &dyn ProfilingAgent
) -> Result<Arc<Self>, SetupError>[src]Creates CompiledModule directly from CompilationArtifacts.
pub fn compilation_artifacts(&self) -> &CompilationArtifacts[src]
pub fn compilation_artifacts(&self) -> &CompilationArtifacts[src]Extracts CompilationArtifacts from the compiled module.
pub fn module_mut(&mut self) -> Option<&mut Module>[src]
pub fn module_mut(&mut self) -> Option<&mut Module>[src]Return a reference to a mutable module (if possible).
pub fn finished_functions(
&self
) -> &PrimaryMap<DefinedFuncIndex, *mut [VMFunctionBody]>[src]
pub fn finished_functions(
&self
) -> &PrimaryMap<DefinedFuncIndex, *mut [VMFunctionBody]>[src]Returns the map of all finished JIT functions compiled for this module
pub fn trampolines(&self) -> &[(SignatureIndex, VMTrampoline)][src]
pub fn trampolines(&self) -> &[(SignatureIndex, VMTrampoline)][src]Returns the per-signature trampolines for this module.
pub fn stack_maps(
&self
) -> impl Iterator<Item = (*mut [VMFunctionBody], &[StackMapInformation])>[src]
pub fn stack_maps(
&self
) -> impl Iterator<Item = (*mut [VMFunctionBody], &[StackMapInformation])>[src]Returns the stack map information for all functions defined in this module.
The iterator returned iterates over the span of the compiled function in memory with the stack maps associated with those bytes.
pub fn func_by_pc(&self, pc: usize) -> Option<(DefinedFuncIndex, usize, usize)>[src]
pub fn func_by_pc(&self, pc: usize) -> Option<(DefinedFuncIndex, usize, usize)>[src]Lookups a defined function by a program counter value.
Returns the defined function index, the start address, and the end address (exclusive).
pub fn func_info(&self, index: DefinedFuncIndex) -> &FunctionInfo[src]
pub fn func_info(&self, index: DefinedFuncIndex) -> &FunctionInfo[src]Gets the function information for a given function index.
pub fn jit_code_ranges<'a>(
&'a self
) -> impl Iterator<Item = (usize, usize)> + 'a[src]
pub fn jit_code_ranges<'a>(
&'a self
) -> impl Iterator<Item = (usize, usize)> + 'a[src]Returns all ranges covered by JIT code.
pub fn code(&self) -> &Arc<ModuleCode>[src]
pub fn code(&self) -> &Arc<ModuleCode>[src]Returns module’s JIT code.
pub fn symbolize_context(&self) -> Result<Option<SymbolizeContext>, Error>[src]
pub fn symbolize_context(&self) -> Result<Option<SymbolizeContext>, Error>[src]Creates a new symbolication context which can be used to further symbolicate stack traces.
Basically this makes a thing which parses debuginfo and can tell you what filename and line number a wasm pc comes from.
pub fn has_unparsed_debuginfo(&self) -> bool[src]
pub fn has_unparsed_debuginfo(&self) -> bool[src]Returns whether the original wasm module had unparsed debug information based on the tunables configuration.