Struct wasmtime_jit::Compiler[][src]

pub struct Compiler { /* fields omitted */ }
A WebAssembly code JIT compiler.

A Compiler instance owns the executable memory that it allocates.

TODO: Evolve this to support streaming rather than requiring a &[u8] containing a whole wasm module at once.

TODO: Consider using cranelift-module.

Implementations

impl Compiler[src]

pub fn new(
    isa: Box<dyn TargetIsa>,
    strategy: CompilationStrategy,
    tunables: Tunables,
    features: WasmFeatures
) -> Self
[src]

Construct a new Compiler.

impl Compiler[src]

pub fn isa(&self) -> &dyn TargetIsa[src]

Return the isa.

pub fn strategy(&self) -> CompilationStrategy[src]

Return the compiler’s strategy.

pub fn frontend_config(&self) -> TargetFrontendConfig[src]

Return the target’s frontend configuration settings.

pub fn tunables(&self) -> &Tunables[src]

Return the tunables in use by this engine.

pub fn features(&self) -> &WasmFeatures[src]

Return the enabled wasm features.

pub fn compile<'data>(
    &self,
    translation: &mut ModuleTranslation<'_>,
    types: &TypeTables
) -> Result<Compilation, SetupError>
[src]

Compile the given function bodies.