pub struct Compiler { /* private fields */ }
A WebAssembly code JIT compiler.

A Compiler instance owns the executable memory that it allocates.

TODO: Evolve this to support streaming rather than requiring a &[u8] containing a whole wasm module at once.

TODO: Consider using cranelift-module.

Implementations

Construct a new Compiler.

Return the isa.

Return the target’s frontend configuration settings.

Return the tunables in use by this engine.

Return the enabled wasm features.

Compile the given function bodies.