Struct wasmtime_jit::SymbolizeContext[][src]

pub struct SymbolizeContext { /* fields omitted */ }
A context which contains dwarf debug information to translate program counters back to filenames and line numbers.

Implementations

impl SymbolizeContext[src]

pub fn addr2line(&self) -> &Context<EndianSlice<'_, LittleEndian>>[src]

Returns access to the addr2line::Context which can be used to query frame information with.

pub fn code_section_offset(&self) -> u64[src]

Returns the offset of the code section in the original wasm file, used to calculate lookup values into the DWARF.